Crate crisp_typeck

Crate crisp_typeck 

HM-style type inference and constraint solving (spec 3.4).

Structs

InferredSig
NumericCoercion
Inserted intfloat (or explicit as) recorded for CIR / reveal (#112).
RustExternSig
Declared extern rust function used to type imported crate items (#116).
TypeChecker
TypedCrate

Enums

Ty
TypeError
TypeWarning

Functions

format_sig
format_ty
is_arith_bound
Prelude arithmetic traits inferred from + - * / (spec 15.4).
rust_import_returns_result
Whether a known rust = true import returns Rust Result and should lower via Crisp ? / ambient errors (spec 14.2) instead of panic .expect.
rust_op_bound
Prelude operator trait → std::ops bound (spec 15.4).
subst_named